Crate near_lake_primitives

Crate near_lake_primitives 

Re-exports

pub use near_indexer_primitives;
pub use near_indexer_primitives::near_primitives;

Modules

actions
block
delegate_actions
events
receipts
state_changes
transactions

Structs

AccountId
NEAR Account Identifier.
Block
A structure that represents an entire block in the NEAR blockchain. It is a high-level structure that is built on top of the low-level StreamerMessage structure.
BlockHeader
Replacement for BlockHeaderView from near-primitives. Shrank and simplified. We were trying to leave only the fields indexer developers might be interested in.
CryptoHash
A 256-bit hash used in NEAR Protocol.
Event
Hight-level representation of the Event according to the Events Format. In addition to the event this structure holds the data about the related Receipt: receipt_id, receiver_id and predecessor_id. All these fields are accessible via the corresponding getters.
IndexerShard
RawEvent
This structure is an honest representation of the Events Format standard described here https://nomicon.io/Standards/EventsFormat
Receipt
Simplified representation of the Receipt.
StateChange
Represents the changes to the state of the account.
StreamerMessage
Resulting struct represents block with chunks
Transaction
High-level representation of the Transaction.

Enums

Action
High-level representation of the Action.
DelegateAction
Similarly to the Action enum, this enum represents the different types of actions that can be delegated to a contract.
ReceiptKind
Represents the Receipt kind: Action or Data.
StateChangeCause
StateChangeValue

Traits

EventsTrait

Type Aliases

ReceiptId
Since both transactions::Transaction hash and receipts::Receipt id are the crate::CryptoHash type, we use this type alias to make the code more readable.