Re-exports
pub use near_indexer_primitives;pub use near_indexer_primitives::near_primitives;
Modules
Structs
- Account
Id - NEAR Account Identifier.
- Block
- A structure that represents an entire block in the NEAR blockchain. It is a high-level structure that is built on top of the low-level StreamerMessage structure.
- Block
Header - Replacement for
BlockHeaderViewfromnear-primitives. Shrank and simplified. We were trying to leave only the fields indexer developers might be interested in. - Crypto
Hash - A 256-bit hash used in NEAR Protocol.
- Event
- Hight-level representation of the Event according to the Events Format.
In addition to the event this structure holds the data about the related Receipt:
receipt_id,receiver_idandpredecessor_id. All these fields are accessible via the corresponding getters. - Indexer
Shard - RawEvent
- This structure is an honest representation of the Events Format standard described here https://nomicon.io/Standards/EventsFormat
- Receipt
- Simplified representation of the
Receipt. - State
Change - Represents the changes to the state of the account.
- Streamer
Message - Resulting struct represents block with chunks
- Transaction
- High-level representation of the
Transaction.
Enums
- Action
- High-level representation of the
Action. - Delegate
Action - Similarly to the Action enum, this enum represents the different types of actions that can be delegated to a contract.
- Receipt
Kind - Represents the Receipt kind: Action or Data.
- State
Change Cause - State
Change Value
Traits
Type Aliases
- Receipt
Id - Since both transactions::Transaction hash and receipts::Receipt id are the crate::CryptoHash type, we use this type alias to make the code more readable.